@@ -8,6 +8,8 @@ import jsii
 import publication
 import typing_extensions
 
+import aws_cdk.aws_autoscaling._jsii
+import aws_cdk.aws_autoscaling_hooktargets._jsii
 import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_lambda._jsii
@@ -18,7 +20,7 @@ import aws_cdk.custom_resources._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-gitlab-runner", "1.75.8", __name__[0:-6], "cdk-gitlab-runner@1.75.8.jsii.tgz"
+    "cdk-gitlab-runner", "1.75.9", __name__[0:-6], "cdk-gitlab-runner@1.75.9.jsii.tgz"
 )
 
 __all__ = [
